@@ -14,7 +14,7 @@ class Space:
         	if actioner_type == 'int':
         		sample[i] = random.choice(list(actioner_range))
         	elif actioner_type == 'float':
-        		sample[i] = random.random(actioner_range)
+        		sample[i] = actioner_range[0] + (actioner_range[1]-actioner_range[0])*random.random()
         return sample
 
 
